==> neo4j-cypher-interpreted-runtime-4.4.23-sources.jar: org/neo4j/cypher/internal/runtime/interpreted/commands/expressions/WithinBBoxFunction.scala <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.runtime.interpreted.commands.expressions

import org.neo4j.cypher.internal.runtime.ReadableRow
import org.neo4j.cypher.internal.runtime.interpreted.commands.AstNode
import org.neo4j.cypher.internal.runtime.interpreted.pipes.QueryState
import org.neo4j.cypher.operations.CypherFunctions
import org.neo4j.values.AnyValue

case class WithinBBoxFunction(point: Expression, lowerLeft: Expression, upperRight: Expression) extends Expression {

  override def apply(row: ReadableRow, state: QueryState): AnyValue = CypherFunctions.withinBBox(point(row, state), lowerLeft(row, state), upperRight(row, state))

  override def rewrite(f: Expression => Expression): Expression = f(WithinBBoxFunction(point, lowerLeft, upperRight))

  override def arguments: Seq[Expression] = point.arguments ++ lowerLeft.arguments ++ upperRight.arguments

  override def children: Seq[AstNode[_]] = Seq(point, lowerLeft, upperRight)

  override def toString: String = s"WithinBBox($point, $lowerLeft, $upperRight)"
}

==> neo4j-cypher-interpreted-runtime-5.6.0-sources.jar: org/neo4j/cypher/internal/runtime/interpreted/commands/expressions/WithinBBoxFunction.scala <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.runtime.interpreted.commands.expressions

import org.neo4j.cypher.internal.runtime.ReadableRow
import org.neo4j.cypher.internal.runtime.interpreted.commands.AstNode
import org.neo4j.cypher.internal.runtime.interpreted.pipes.QueryState
import org.neo4j.cypher.operations.CypherFunctions
import org.neo4j.values.AnyValue

case class WithinBBoxFunction(point: Expression, lowerLeft: Expression, upperRight: Expression) extends Expression {

  override def apply(row: ReadableRow, state: QueryState): AnyValue =
    CypherFunctions.withinBBox(point(row, state), lowerLeft(row, state), upperRight(row, state))

  override def rewrite(f: Expression => Expression): Expression = f(WithinBBoxFunction(point, lowerLeft, upperRight))

  override def arguments: collection.Seq[Expression] = point.arguments ++ lowerLeft.arguments ++ upperRight.arguments

  override def children: collection.Seq[AstNode[_]] = Seq(point, lowerLeft, upperRight)

  override def toString: String = s"WithinBBox($point, $lowerLeft, $upperRight)"
}
